==> nextcloud-app-bookmarks-1%3A2.3.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "Not allowed to access folder to import into" : "Ne permesita aliri la dosierujon, en kiu oni devas enmeti la datumojn",
    "Failed to import one bookmark, because: " : "Malsukcesis enporti unu legosignon ĉar:",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
    "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
    "This app provides you with a web interface for collecting and organizing bookmarks to the sites on the web that are precious to you. You can browse and filter your bookmarks via tags and folders and by using the built-in search feature. Furthermore, in order to access your bookmarks anywhere, it also allows you to synchronize third-party clients via a built-in REST API -- in your browsers and on your phone.\n\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tiu aplikaĵo estas TTT-interfaco por kolekti kaj organizi legosignoj. Vi povas navigi kaj filtri viajn legosignojn per etikedoj, dosierujoj kaj ankaŭ uzo de serĉo. Plie, vi povas sinkronigi al eksteraj liverantoj per provizita „REST API“ — retumile kaj poŝtelefone.\n\nVidu liston de eksteraj klientoj ĉi tie: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Move" : "Movi",
    "Delete" : "Forigi",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Save" : "Konservi",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New folder" : "Nova dosierujo",
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "Enter a link" : "Entajpu ligilon",
    "Create" : "Krei",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Root folder" : "Radika dosierujo",
    "New Bookmark" : "Nova legosigno",
    "All Bookmarks" : "Ĉiuj legosignoj",
    "Recent Bookmarks" : "Lastaj legosignoj",
    "Untagged" : "Sen etikedo",
    "Import" : "Importi",
    "Export" : "Eksporti",
    "Sorting" : "Ordigo",
    "Recently added" : "Lastaj aldonoj",
    "Alphabetically" : "Alfabete",
    "Most visited" : "Plej vizititaj",
    "Last modified" : "laŭ lasta modifo",
    "RSS Feed" : "RSS-fluo",
    "Clear data" : "Forviŝi datumojn",
    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
    "Bookmarklet" : "Legosignilo",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Client apps" : "Klientaj aplikaĵoj",
    "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
    "Creation date" : "Krea dato",
    "Tags" : "Etikedoj",
    "Select tags are create new ones" : "Elekti etikedojn aŭ krei novajn",
    "Notes" : "Notoj",
    "Sharing" : "Kunhavigo",
    "{time} ago" : "antaŭ {time}",
    "Select" : "Elekti",
    "Previews" : "Antaŭrigardoj",
    "Screeenly" : "Screeenly",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "Privacy" : "Privateco",
    "Performance" : "Rendimento",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "Add a bookmark" : "Aldoni legosignon",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Enter bookmark url" : "Entajpu retadreson de la legosigno",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to move parts of selection" : "Movo de partoj de la elekto malsukcesis",
    "Failed to delete parts of selection" : "Malsukceso forigi partojn de elekto",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Failed to change setting" : "Ŝanĝo de agordo malsukcesis",
    "Failed to load setting " : "Ŝargo de agordo malsukcesis",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A2.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/eo.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Legosignaro",
    "Not allowed to access folder to import into" : "Ne permesita aliri la dosierujon, en kiu oni devas enmeti la datumojn",
    "Failed to import one bookmark, because: " : "Malsukcesis enporti unu legosignon ĉar:",
    "No file provided for import" : "Neniu dosiero provizita por enporto",
    "Unsupported file type for import" : "Nesubtenita dosiertipo por enporto",
    "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
    "This app provides you with a web interface for collecting and organizing bookmarks to the sites on the web that are precious to you. You can browse and filter your bookmarks via tags and folders and by using the built-in search feature. Furthermore, in order to access your bookmarks anywhere, it also allows you to synchronize third-party clients via a built-in REST API -- in your browsers and on your phone.\n\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tiu aplikaĵo estas TTT-interfaco por kolekti kaj organizi legosignoj. Vi povas navigi kaj filtri viajn legosignojn per etikedoj, dosierujoj kaj ankaŭ uzo de serĉo. Plie, vi povas sinkronigi al eksteraj liverantoj per provizita „REST API“ — retumile kaj poŝtelefone.\n\nVidu liston de eksteraj klientoj ĉi tie: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Select bookmark" : "Elekti legosignon",
    "Details" : "Detaloj",
    "Rename" : "Alinomi",
    "Move" : "Movi",
    "Delete" : "Forigi",
    "Enter bookmark title" : "Entajpu titolon de la legosigno",
    "Save" : "Konservi",
    "No bookmarks here" : "Neniu legosigno ĉi tie",
    "Try changing your query or add some using the button on the left." : "Provu ŝanĝi vian peton aŭ aldoni kelkajn per uzo de la butono maldekstre.",
    "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
    "New folder" : "Nova dosierujo",
    "Grid view" : "Krada vido",
    "List view" : "Lista vido",
    "Move selection" : "Movi elekton",
    "Delete selection" : "Forigi elekton",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
    "Enter a link" : "Entajpu ligilon",
    "Create" : "Krei",
    "Enter folder title" : "Entajpu titolon de la dosierujo",
    "Root folder" : "Radika dosierujo",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movo de %n dosierujo","Movo de %n dosierujoj"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
    "New Bookmark" : "Nova legosigno",
    "All Bookmarks" : "Ĉiuj legosignoj",
    "Recent Bookmarks" : "Lastaj legosignoj",
    "Untagged" : "Sen etikedo",
    "Import" : "Importi",
    "Export" : "Eksporti",
    "Sorting" : "Ordigo",
    "Recently added" : "Lastaj aldonoj",
    "Alphabetically" : "Alfabete",
    "Most visited" : "Plej vizititaj",
    "Last modified" : "laŭ lasta modifo",
    "RSS Feed" : "RSS-fluo",
    "This is an RSS feed of the current result set with access restricted to you." : "Tio estas (RSS) abonfluo de la nuna rezultaro kun aliro nur por vi.",
    "Clear data" : "Forviŝi datumojn",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Porĉiame forigi ĉiujn legosignojn el via konto. Ne eblos malfari tion!",
    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
    "Bookmarklet" : "Legosignilo",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Ŝovu tion al via retumila legosignaro  kaj alklaku ĝin por rapide aldoni al viaj legosignoj retpaĝon",
    "Add to {instanceName}" : "Aldoni al {instanceName}",
    "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
    "Client apps" : "Klientaj aplikaĵoj",
    "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
    "Creation date" : "Krea dato",
    "Tags" : "Etikedoj",
    "Select tags are create new ones" : "Elekti etikedojn aŭ krei novajn",
    "Notes" : "Notoj",
    "Sharing" : "Kunhavigo",
    "{time} ago" : "antaŭ {time}",
    "Select" : "Elekti",
    "Previews" : "Antaŭrigardoj",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Por vidigi realajn ekrankopiojn de viaj legosignoj, Legosignaro povas uzi servon de ekstera liveranto por krei ilin.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Vi povas aŭ krei senpagan konton ĉe screeenly.com aŭ instali vian propran servilon.",
    "Screeenly API URL" : "API-adreso de Screeenly",
    "Screeenly API key" : "API-ŝlosilo de Screeenly",
    "Privacy" : "Privateco",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
    "Performance" : "Rendimento",
    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "Ĉe servo kun multe da uzantoj, eble utilas limigi la nombrojn de legosignoj por ĉiu konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maksimuma nombro de legosignoj en unu konto. (0 por ne limigi; defaŭlte ne estas limigo)",
    "Failed to load settings" : "Ŝargo de agordoj malsukcesis",
    "Failed to save settings" : "Konservo de agordoj malsukcesis",
    "Add a bookmark" : "Aldoni legosignon",
    "This URL is already bookmarked! Overwrite?" : "Tiu adreso jam ekzistas en viaj legosignoj! Anstataŭigi ĝin?",
    "Title" : "Titolo",
    "Link" : "Ligilo",
    "Enter bookmark url" : "Entajpu retadreson de la legosigno",
    "Failed to find existing bookmark" : "Trovo de jam ekzistanta legosigno malsukcesis",
    "Failed to create bookmark" : "Kreo de legosigno malsukcesis",
    "Failed to save bookmark" : "Konservo de legosigno malsukcesis",
    "Failed to move bookmark" : "Movo de legosigno malsukcesis",
    "Failed to delete bookmark" : "Forigo de legosigno malsukcesis",
    "Failed to load tags" : "Ŝargo de la etikedoj malsukcesis",
    "Failed to load folders" : "Ŝargo de la dosierujoj malsukcesis",
    "Failed to delete folder" : "Forigo de la dosierujo malsukcesis",
    "Failed to create folder" : "Kreo de dosierujo malsukcesis",
    "Failed to move parts of selection" : "Movo de partoj de la elekto malsukcesis",
    "Failed to delete parts of selection" : "Malsukceso forigi partojn de elekto",
    "Failed to fetch bookmarks." : "Ricevo de legosignoj malsukcesis.",
    "Failed to change setting" : "Ŝanĝo de agordo malsukcesis",
    "Failed to load setting " : "Ŝargo de agordo malsukcesis",
    "Bookmarks feed" : "Fluo de legosignoj"
},
"nplurals=2; plural=(n != 1);");
